# Sweaty Goals

Sweaty goals is CLI tool that retrieves the latest football (soccer) matches happening around the world. Never miss a 
single game of football!

## Installation

## Usage
- Run in cli: `sweatygoals matches` to retrieve the latest football matches. Example output:
![Football matches result](https://raw.githubusercontent.com/AndresXI/sweaty-goals/master/matches.png)
- To navigate to match url (opens a web page with full match details) run: `sweatygoals matches -t "<MATCH TITLE>"`, ex: 
`sweatygoals -t "Arsenal - Liverpool"`, note: football match title must be in quotation marks and match the 
title in the MATCH column
 